@@ -6,7 +6,9 @@ use warnings;
 
 #------------------------------------------------------------------------------------------------------
 
-sub display_popup_menu { ; }
+sub display_popup_menu
+{
+}
 
 #------------------------------------------------------------------------------------------------------
 
