@@ -36,10 +36,11 @@ return
 	sub
 		{
 		my ($self) = @_ ;
-		
-		my $element = $self->add_new_element_named('Asciio/box', $x, $y) ;
+
+		my $element = $self->add_new_element_named('stencils/asciio/box', $x, $y) ;
+
 		$element->set_text($title, $text) ;
-		
+
 		$self->select_elements($select, $element) ;
 		
 		return $element ;
@@ -52,8 +53,7 @@ return
 	sub
 		{
 		my ($self) = @_ ;
-		$self->select_all_elements() ;
-		$self->delete_elements($self->get_selected_elements(1)) ;
+		$self->run_actions_by_name('Select all elements', 'Delete selected elements') ;
 		} ;
 }
 
