@@ -11,35 +11,33 @@ use Readonly ;
 
 #-----------------------------------------------------------------------------
 
-Readonly my $DEFAULT_ARROW_TYPE=> 
-	# name: $start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection
-	[
-		['origin'     , '*',  '?', '?', '?', '?', '?', '?', 1],
-		['up'         , "'",  '|', '?', '?', '.', '?', '?', 1],
-		['down'       , '.',  '|', '?', '?', "'", '?', '?', 1],
-		['left'       , '-',  '-', '?', '?', '-', '?', '?', 1],
-		['right'      , '-',  '-', '?', '?', '-', '?', '?', 1],
-		['up-left'    , "'", '\\', '.', '-', '-', '|', "'", 1],
-		['left-up'    , '-', '\\', "'", '-', '.', '|', "'", 1],
-		['down-left'  , '.',  '/', "'", '-', '-', '|', "'", 1],
-		['left-down'  , '-',  '/', '.', '-', "'", '|', "'", 1],
-		['up-right'   , "'",  '/', '.', '-', '-', '|', "'", 1],
-		['right-up'   , '-',  '/', "'", '-', '.', '|', "'", 1],
-		['down-right' , '.', '\\', "'", '-', '-', '|', "'", 1],
-		['right-down' , '-', '\\', '.', '-', "'", '|', "'", 1],
-	] ;
-
-#-----------------------------------------------------------------------------
+Readonly my $DEFAULT_GLYPHS=> 
+	#name: => [$start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection]
+	{
+	'origin' => [ '*', '?', '?', '?', '?', '?', '?'],
+	'up'=> [ "'", '|', '?', '?', '.', '?', '?'],
+	'down' => [ '.', '|', '?', '?', "'", '?', '?'],
+	'left' => [ '-', '-', '?', '?', '-', '?', '?'],
+	'right' => [ '-', '-', '?', '?', '-', '?', '?'],
+	'upleft' => [ "'", '\\', '.', '-', '-', '|', "'"],
+	'leftup' => [ '-', '\\', "'", '-', '.', '|', "'"],
+	'downleft' => [ '.', '/', "'", '-', '-', '|', "'"],
+	'leftdown' => [ '-', '/', '.', '-', "'", '|', "'"],
+	'upright' => [ "'", '/', '.', '-', '-', '|', "'"],
+	'rightup' => [ '-', '/', "'", '-', '.', '|', "'"],
+	'downright' => [ '.', '\\', "'", '-', '-', '|', "'"],
+	'rightdown' => [ '-', '\\', '.', '-', "'", '|', "'"],
+	} ;
 
 sub new
 {
 my ($class, $element_definition) = @_ ;
 
 my $self = bless  {}, __PACKAGE__ ;
-
+	
 $self->setup
 	(
-	$element_definition->{ARROW_TYPE} || $DEFAULT_ARROW_TYPE,
+	$element_definition->{GLYPHS} || $DEFAULT_GLYPHS,
 	$element_definition->{END_X}, $element_definition->{END_Y},
 	$element_definition->{DIRECTION},
 	$element_definition->{EDITABLE},
@@ -52,63 +50,19 @@ return $self ;
 
 sub setup
 {
-my ($self, $arrow_type, $end_x, $end_y, $direction, $editable) = @_ ;
-
-my $glyphs = 
-{
-	# name => [$start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection]
-	$arrow_type->[0][0] => [@{$arrow_type->[0]}[1..7]],
-	$arrow_type->[1][0] => [@{$arrow_type->[1]}[1..7]],
-	$arrow_type->[2][0] => [@{$arrow_type->[2]}[1..7]],
-	$arrow_type->[3][0] => [@{$arrow_type->[3]}[1..7]],
-	$arrow_type->[4][0] => [@{$arrow_type->[4]}[1..7]],
-	$arrow_type->[5][0] => [@{$arrow_type->[5]}[1..7]],
-	$arrow_type->[6][0] => [@{$arrow_type->[6]}[1..7]],
-	$arrow_type->[7][0] => [@{$arrow_type->[7]}[1..7]],
-	$arrow_type->[8][0] => [@{$arrow_type->[8]}[1..7]],
-	$arrow_type->[9][0] => [@{$arrow_type->[9]}[1..7]],
-	$arrow_type->[10][0] => [@{$arrow_type->[10]}[1..7]],
-	$arrow_type->[11][0] => [@{$arrow_type->[11]}[1..7]],
-	$arrow_type->[12][0] => [@{$arrow_type->[12]}[1..7]],
-} ;
+my ($self, $glyphs, $end_x, $end_y, $direction, $editable) = @_ ;
 
 (my ($stripes, $width, $height), $direction) = get_arrow($glyphs, $end_x, $end_y, $direction) ;
 
-my ($ex1, $ey1, $ex2, $ey2) ;
-
-if ($end_x < 0)
-    {
-    $ex1 = $end_x ;
-    $ex2 = 1 ;
-    }
-else
-    {
-    $ex1 = 0 ;
-    $ex2 = $end_x + 1 ;
-    }
-
-if ($end_y < 0)
-    {
-    $ey1 = $end_y ;
-    $ey2 = 1 ;
-    }
-else
-    {
-    $ey1 = 0 ;
-    $ey2 = $end_y + 1 ;
-    }
-
 $self->set
 	(
 	GLYPHS => $glyphs,
-	ARROW_TYPE => $arrow_type,
 	STRIPES => $stripes,
 	WIDTH => $width,
 	HEIGHT => $height,
 	DIRECTION => $direction,
 	END_X => $end_x,
 	END_Y => $end_y,
-	EXTENTS => [$ex1, $ey1, $ex2, $ey2],
 	) ;
 }
 
@@ -149,11 +103,11 @@ my @position_to_direction =
 	) ;
 
 $direction = $position_to_direction
-		[$end_x == 0 ? CENTER : $end_x < 0 ? LEFT : RIGHT]
-		[$end_y == 0 ? CENTER : $end_y < 0 ? UP : DOWN] ;
+			[$end_x == 0 ? CENTER : $end_x < 0 ? LEFT : RIGHT]
+			[$end_y == 0 ? CENTER : $end_y < 0 ? UP : DOWN] ;
 
 my $drawing_sub = $direction_to_arrow{$direction} ;
- 
+
 return($drawing_sub->($glyphs, $end_x, $end_y), $direction) ;
 }
 
@@ -174,8 +128,8 @@ push @{$stripes},
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 } 
 
@@ -198,7 +152,7 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
+	};
 
 for(1 .. $height - 1)
 	{
@@ -211,7 +165,7 @@ for(1 .. $height - 1)
 		'Y_OFFSET' => -$_,
 		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -219,7 +173,7 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => $end_y,
-	} ;
+	};
 
 return(\@stripes, $width, $height) ;
 }
@@ -243,7 +197,7 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
+	};
 
 for(1 .. $height - 1)
 	{
@@ -254,9 +208,9 @@ for(1 .. $height - 1)
 		'WIDTH' => 1,
 		'X_OFFSET' => 0,
 		'Y_OFFSET' => $_,
-		} ;
+		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -264,8 +218,8 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => $end_y,
-	} ;
-
+	};
+	
 return(\@stripes, $width, $height) ;
 }
 
@@ -289,8 +243,8 @@ push @stripes,
 	'WIDTH' => length($stripe),
 	'X_OFFSET' => $end_x,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return(\@stripes, $width, $height) ;
 }
 
@@ -314,8 +268,8 @@ push @stripes,
 	'WIDTH' => length($stripe),
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return(\@stripes, $width, $height) ;
 }
 
@@ -324,7 +278,8 @@ return(\@stripes, $width, $height) ;
 sub draw_upright
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'up-right'}} ;
+
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{upright}} ;
 
 my ($width, $height) = ( $end_x + 1, 	-$end_y + 1) ;
 
@@ -343,8 +298,8 @@ if($end_x >= -$end_y) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++, # diagonal
 		'Y_OFFSET' => $position_y--, # diagonal
-		} ;
-	
+		};
+		
 	for(-$position_y .. (-$end_y - 1))
 		{
 		push @stripes,
@@ -354,9 +309,9 @@ if($end_x >= -$end_y) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++, # diagonal
 			'Y_OFFSET' => $position_y--, # diagonal
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -364,8 +319,8 @@ if($end_x >= -$end_y) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++, # going right
 		'Y_OFFSET' => $position_y, # staying horizontal
-		} ;
-	
+		};
+
 	if($end_x > -$end_y)
 		{
 		for($position_x .. ($end_x - 1))
@@ -377,9 +332,9 @@ if($end_x >= -$end_y) # enought horizontal length to have a proper diagonal up
 				'WIDTH' => 1,
 				'X_OFFSET' => $position_x++, # going right
 				'Y_OFFSET' => $position_y, # staying horizontal
-				} ;
+				};
 			}
-		
+			
 		push @stripes,
 			{
 			'HEIGHT' => 1,
@@ -387,10 +342,10 @@ if($end_x >= -$end_y) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, # finished
 			'Y_OFFSET' => $position_y, # finished
-			} ;
+			};
 		}
 	}
-
+	
 if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal up
 	{
 	my $number_of_verticals = ($height - $width) - 1 ;
@@ -402,8 +357,8 @@ if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal u
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y--, # up
-		} ;
-	
+		};
+		
 	for(1 .. $number_of_verticals)
 		{
 		push @stripes,
@@ -413,9 +368,9 @@ if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal u
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -424,7 +379,7 @@ if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal u
 		'X_OFFSET' => $position_x++, # going right
 		'Y_OFFSET' => $position_y--, # going up
 		} if($end_x != 0) ;
-	
+
 	my $number_of_diagonals = $height - ($number_of_verticals + 3) ;
 	
 	for(1 .. $number_of_diagonals)
@@ -436,9 +391,9 @@ if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal u
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++, # going right
 			'Y_OFFSET' => $position_y--, # going up
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -446,7 +401,7 @@ if($end_x < -$end_y) # not enought horizontal length to have a proper diagonal u
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
@@ -458,7 +413,7 @@ sub draw_upleft
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'up-left'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{upleft}} ;
 
 my ($width, $height) = ( -$end_x + 1, 	-$end_y + 1) ;
 
@@ -477,8 +432,8 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x--,
 		'Y_OFFSET' => $position_y--,
-		} ;
-	
+		};
+		
 	for(-$position_y .. (-$end_y - 1))
 		{
 		push @stripes,
@@ -488,9 +443,9 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -498,8 +453,8 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x--,
 		'Y_OFFSET' => $position_y,
-		} ;
-	
+		};
+
 	if($width > $height)
 		{
 		for(1 .. ($width - $height) - 1)
@@ -511,9 +466,9 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 				'WIDTH' => 1,
 				'X_OFFSET' => $position_x--, 
 				'Y_OFFSET' => $position_y,
-				} ;
+				};
 			}
-		
+			
 		push @stripes,
 			{
 			'HEIGHT' => 1,
@@ -521,7 +476,7 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x,
 			'Y_OFFSET' => $position_y,
-			} ;
+			};
 		}
 	}
 else
@@ -529,6 +484,7 @@ else
 	my $number_of_verticals = ($height - $width) - 1  ;
 	my $number_of_diagonals = $height - ($number_of_verticals + 3) ;
 	
+	
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -537,7 +493,7 @@ else
 		'X_OFFSET' => $position_x,
 		'Y_OFFSET' => $position_y--, 
 		} ;
-	
+		
 	for(1 .. $number_of_verticals)
 		{
 		push @stripes,
@@ -547,9 +503,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -558,7 +514,7 @@ else
 		'X_OFFSET' => $position_x--,
 		'Y_OFFSET' => $position_y--, 
 		} if($end_x != 0) ;
-	
+		
 	for(1 .. $number_of_diagonals)
 		{
 		push @stripes,
@@ -568,9 +524,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -578,7 +534,7 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
@@ -590,17 +546,22 @@ sub draw_leftup
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'left-up'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{leftup}} ;
 
 my ($width, $height) = ( -$end_x + 1, 	-$end_y + 1) ;
 
 my ($position_x, $position_y) = (0, 0) ;
 my @stripes ;
 
+#~ require Enbugger ;
+#~ Enbugger->stop ;
+
+#~ print "leftup\n" ;
+
 if($width > $height) # enought horizontal length to have a proper diagonal up
 	{
 	my $start_body_connector = $connection . $body_2 x (($width - $height) - 1) . $start ;
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -608,8 +569,8 @@ if($width > $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => length($start_body_connector),
 		'X_OFFSET' => - length($start_body_connector) + 1, 
 		'Y_OFFSET' => $position_y--,
-		} ;
-	
+		};
+		
 	$position_x -= length($start_body_connector) ;
 	
 	for(1 .. ($height - 2))  # two connectors
@@ -621,9 +582,9 @@ if($width > $height) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -631,7 +592,7 @@ if($width > $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x,
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 else
 	{
@@ -645,7 +606,7 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x--, 
 		'Y_OFFSET' => $position_y--,
-		} ;
+		};
 		
 	for(1 .. $number_of_diagonals)
 		{
@@ -656,9 +617,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -667,7 +628,7 @@ else
 		'X_OFFSET' => $position_x,
 		'Y_OFFSET' => $position_y--, 
 		} if($end_x != $end_y) ;
-	
+		
 	for(1 .. $number_of_verticals - 1)
 		{
 		push @stripes,
@@ -677,9 +638,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x,
 			'Y_OFFSET' => $position_y--, 
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -700,13 +661,16 @@ sub draw_rightup
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'right-up'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{rightup}} ;
 
 my ($width, $height) = ( $end_x + 1, 	-$end_y + 1) ;
 
 my ($position_x, $position_y) = (0, 0) ;
 my @stripes ;
 
+#~ require Enbugger ;
+#~ Enbugger->stop ;
+
 if($end_x > -$end_y)
 	{
 	push @stripes,
@@ -716,8 +680,8 @@ if($end_x > -$end_y)
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++,
 		'Y_OFFSET' => $position_y,
-		} ;
-	
+		};
+		
 	for(1 .. ($width - $height) - 1)
 		{
 		push @stripes,
@@ -727,9 +691,9 @@ if($end_x > -$end_y)
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++,
 			'Y_OFFSET' => $position_y,
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -737,8 +701,8 @@ if($end_x > -$end_y)
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++,
 		'Y_OFFSET' => $position_y--, 
-		} ;
-	
+		};
+		
 	for($position_x .. ($end_x - 1))
 		{
 		push @stripes,
@@ -748,9 +712,9 @@ if($end_x > -$end_y)
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++,
 			'Y_OFFSET' => $position_y--, 
-			} ;
+			};
 		}
-	
+			
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -758,7 +722,7 @@ if($end_x > -$end_y)
 		'WIDTH' => 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $end_y,
-		} ;
+		};
 	}
 else
 	{
@@ -774,8 +738,8 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++,
 		'Y_OFFSET' => $position_y--,
-		} ;
-	
+		};
+		
 	for(1 .. $number_of_diagonals)
 		{
 		push @stripes,
@@ -785,9 +749,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -796,7 +760,7 @@ else
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y--,
 		} if $has_diagonal_connection ;
-	
+
 	for(1 .. $number_of_verticals)
 		{
 		push @stripes,
@@ -806,9 +770,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x,
 			'Y_OFFSET' => $position_y--,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -828,13 +792,16 @@ sub draw_downleft
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'down-left'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{downleft}} ;
 
 my ($width, $height) = ( -$end_x + 1,  $end_y + 1) ;
 
 my ($position_x, $position_y) = (0, 0) ;
 my @stripes ;
 
+#~ require Enbugger ;
+#~ Enbugger->stop ;
+
 if($width >= $height) # enought horizontal length to have a proper diagonal up
 	{
 	push @stripes,
@@ -844,8 +811,8 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x--, 
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+		
 	for(1 .. ($height - 2))  # two connectors
 		{
 		push @stripes,
@@ -855,11 +822,10 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
-	my $left_text = ''  ;
-	$left_text .= $body_2 x (($width - $height) - 1)  if $width > $height ;
+		
+	my $left_text = $body_2 x (($width - $height) - 1)  ;
 	
 	if($width > $height)
 		{
@@ -873,7 +839,8 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => length($left_text) + 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
+		
 	}
 else # not enought horizontal length to have a proper diagonal up
 	{
@@ -884,8 +851,8 @@ else # not enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+		
 	for (1 .. ($height - $width) - 1)
 		{
 		push @stripes,
@@ -895,9 +862,9 @@ else # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+		
 	if($end_x != 0)
 		{
 		push @stripes,
@@ -907,9 +874,9 @@ else # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--, 
 			'Y_OFFSET' => $position_y++, 
-			} ;
+			} 
 		}
-	
+		
 	for(1 .. (-$end_x  + $position_x))
 		{
 		push @stripes,
@@ -919,9 +886,9 @@ else # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--, 
 			'Y_OFFSET' => $position_y++, 
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -929,7 +896,7 @@ else # not enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
@@ -941,17 +908,19 @@ sub draw_leftdown
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'left-down'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{leftdown}} ;
 
 my ($width, $height) = ( -$end_x + 1,  $end_y + 1) ;
 
 my ($position_x, $position_y) = (0, 0) ;
 my @stripes ;
 
+#~ require Enbugger ;
+#~ Enbugger->stop ;
+
 if($width >= $height) # enought horizontal length to have a proper diagonal up
 	{
-	my $start_body_connector = $connection;
-	$start_body_connector .= $body_2 x (($width - $height) - 1) if $width > $height ;
+	my $start_body_connector = $connection . $body_2 x (($width - $height) - 1) ;
 	
 	if($width > $height)
 		{
@@ -965,8 +934,8 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => length($start_body_connector),
 		'X_OFFSET' => - length($start_body_connector) + 1, 
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+		
 	$position_x -= length($start_body_connector) ;
 	
 	for(1 .. ($height - 2))  # two connectors
@@ -978,9 +947,9 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--,
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -988,7 +957,7 @@ if($width >= $height) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x,
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 else 
 	{
@@ -999,8 +968,8 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x--, 
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+		
 	for(1 .. (-$end_x  + $position_x))
 		{
 		push @stripes,
@@ -1010,9 +979,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x--, 
 			'Y_OFFSET' => $position_y++, 
-			} ;
+			};
 		}
-	
+		
 	if($end_x != 0)
 		{
 		push @stripes,
@@ -1022,9 +991,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y++, 
-			} ; 
+			} 
 		}
-	
+		
 	for (1 .. ($height - $width) - 1)
 		{
 		push @stripes,
@@ -1034,9 +1003,9 @@ else
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1044,7 +1013,7 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
@@ -1056,7 +1025,7 @@ sub draw_downright
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'down-right'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{downright}} ;
 
 my ($width, $height) = ( $end_x + 1,  $end_y + 1) ;
 
@@ -1075,8 +1044,8 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++, # diagonal
 		'Y_OFFSET' => $position_y++, # diagonal
-		} ;
-	
+		};
+		
 	for($position_y .. ($end_y - 1))
 		{
 		push @stripes,
@@ -1086,9 +1055,9 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++, # diagonal
 			'Y_OFFSET' => $position_y++, # diagonal
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1096,8 +1065,8 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++, # going right
 		'Y_OFFSET' => $position_y, # staying horizontal
-		} ;
-	
+		};
+
 	if($end_x > $end_y)
 		{
 		for($position_x .. ($end_x - 1))
@@ -1109,9 +1078,9 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal up
 				'WIDTH' => 1,
 				'X_OFFSET' => $position_x++, # going right
 				'Y_OFFSET' => $position_y, # staying horizontal
-				} ;
+				};
 			}
-		
+			
 		push @stripes,
 			{
 			'HEIGHT' => 1,
@@ -1119,10 +1088,10 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, # finished
 			'Y_OFFSET' => $position_y, # finished
-			} ;
+			};
 		}
 	}
-
+	
 if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 	{
 	my $number_of_verticals = ($end_y - $end_x) - 1 ;
@@ -1135,7 +1104,7 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y++, 
 		} ;
-	
+		
 	for(1 .. $number_of_verticals)
 		{
 		push @stripes,
@@ -1145,9 +1114,9 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y++, 
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1156,7 +1125,7 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 		'X_OFFSET' => $position_x++, 
 		'Y_OFFSET' => $position_y++, 
 		} if($end_x != 0) ;
-	
+
 	my $number_of_diagonals = $height - ($number_of_verticals + 3) ;
 	
 	for(1 .. $number_of_diagonals)
@@ -1168,9 +1137,9 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++,
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1178,25 +1147,26 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
 }
 
-#----------------------------------------------------------------------------------------------------------
-
 sub draw_rightdown
 {
 my ($glyphs, $end_x, $end_y) = @_ ;
 
-my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{'right-down'}} ;
+my ($start, $body, $connection, $body_2, $end, $vertical, $diagonal_connection) = @{$glyphs->{rightdown}} ;
 
 my ($width, $height) = ( $end_x + 1,  $end_y + 1) ;
 
 my ($position_x, $position_y) = (0, 0) ;
 my @stripes ;
 
+#~ require Enbugger ;
+#~ Enbugger->stop ;
+
 if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 	{
 	if($end_x > $end_y)
@@ -1208,8 +1178,8 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++, # going right
 			'Y_OFFSET' => $position_y, # stay on this line
-			} ;
-		
+			};
+			
 		for(1 .. ($end_x  - $end_y) - 1)
 			{
 			push @stripes,
@@ -1219,10 +1189,10 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 				'WIDTH' => 1,
 				'X_OFFSET' => $position_x++, 
 				'Y_OFFSET' => $position_y, 
-				} ;
+				};
 			}
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1230,8 +1200,8 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x++,
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+
 	for(1 .. ($end_y - $position_y))
 		{
 		push @stripes,
@@ -1241,9 +1211,9 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x++,
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1251,9 +1221,9 @@ if($end_x >= $end_y) # enought horizontal length to have a proper diagonal down
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x,
 		'Y_OFFSET' => $position_y,
-		} ;
+		};
 	}
-
+	
 if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 	{
 	push @stripes,
@@ -1263,8 +1233,8 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y++,
-		} ;
-	
+		};
+		
 	for(1 .. (($end_x - 1) - $position_x))
 		{
 		$position_x++ ;
@@ -1275,9 +1245,9 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x,
 			'Y_OFFSET' => $position_y++,
-			} ;
+			};
 		}
-	
+		
 	if($end_x != 0)
 		{
 		$position_x++ ;
@@ -1288,9 +1258,9 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 			'WIDTH' => 1,
 			'X_OFFSET' => $position_x, 
 			'Y_OFFSET' => $position_y++,
-			} ; 
+			} 
 		}
-	
+		
 	for (0 .. ($end_y -$position_y) - 1)
 		{
 		push @stripes,
@@ -1302,7 +1272,7 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 			'Y_OFFSET' => $position_y++,
 			};
 		}
-	
+		
 	push @stripes,
 		{
 		'HEIGHT' => 1,
@@ -1310,7 +1280,7 @@ if($end_x < $end_y) # not enought horizontal length to have a proper diagonal up
 		'WIDTH' => 1,
 		'X_OFFSET' => $position_x, 
 		'Y_OFFSET' => $position_y++,
-		} ;
+		};
 	}
 
 return(\@stripes, $width, $height) ;
@@ -1355,13 +1325,11 @@ my ($self, $name) = @_ ;
 
 if($name eq 'start')
 	{
-	return( {X => 0, Y => 0, NAME => 'start', CHAR => $self->{GLYPHS}{$self->{DIRECTION}}[0]} ) if exists $self->{GLYPHS} ;
-	return( {X => 0, Y => 0, NAME => 'start', CHAR => '?'} ) ;
+	return( {X => 0, Y => 0, NAME => 'start'} ) ;
 	}
 elsif($name eq 'end')
 	{
-	return( {X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end', CHAR => $self->{GLYPHS}{$self->{DIRECTION}}[4]} ) if exists $self->{GLYPHS} ;
-	return( {X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end', CHAR => '?'} ) ;
+	return( {X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end'} ) ;
 	}
 else
 	{
@@ -1378,8 +1346,6 @@ my ($self) = @_ ;
 return $self->{DIRECTION} ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub change_direction
 {
 my ($self, $x, $y) = @_ ;
@@ -1411,7 +1377,7 @@ elsif($connector_name eq 'end')
 	{
 	my ($x_offset, $y_offset, $width, $height, undef) = 
 		$self->resize(-1, -1, $self->{END_X} + $x_offset, $self->{END_Y} + $y_offset, $hint) ;
-	
+
 	return 
 		$x_offset, $y_offset, $width, $height,
 		{X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end'} ;
@@ -1453,64 +1419,30 @@ if($is_start)
 	my $new_end_x = $self->{END_X} - $x_offset ;
 	my $new_end_y = $self->{END_Y} - $y_offset ;
 	
-	$self->setup($self->{ARROW_TYPE}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION}, $self->{EDITABLE}) ;
-	
+	$self->setup($self->{GLYPHS}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION}, $self->{EDITABLE}) ;
+
 	return($x_offset, $y_offset, $self->{WIDTH}, $self->{HEIGHT}, 'start') ;
 	}
 else
 	{
 	my $new_end_x = $new_x ;
 	my $new_end_y = $new_y ;
-	
-	$self->setup($self->{ARROW_TYPE}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION}, $self->{EDITABLE}) ;
-	
+
+	$self->setup($self->{GLYPHS}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION}, $self->{EDITABLE}) ;
+
 	return(0, 0, $self->{WIDTH}, $self->{HEIGHT}, 'end') ;
 	}
 }
 
 #-----------------------------------------------------------------------------
 
-sub get_all_points { my ($self) = @_ ; $self->get_connector_points() ; }
-
-#-----------------------------------------------------------------------------
-
-sub get_section_direction { my ($self, $section_index) = @_ ; return $self->{DIRECTION} ; }
-
-#-----------------------------------------------------------------------------
-
-sub edit
-{
-my ($self, $asciio) = @_ ;
-
-$self->display_arrow_edit_dialog() ;
-
-$self->setup
-	(
-	$self->{ARROW_TYPE},
-	$self->{END_X}, $self->{END_Y},
-	$self->{DIRECTION},
-	$self->{EDITABLE},
-	) ;
-}
-
-#-----------------------------------------------------------------------------
-
-sub set_arrow_type
-{
-my ($self, $arrow_type) = @_ ;
-
-delete $self->{CACHE} ;
-
-$self->setup
-	(
-	$arrow_type,
-	$self->{END_X}, $self->{END_Y},
-	$self->{DIRECTION},
-	$self->{EDITABLE},
-	) ;
-}
-
-#-----------------------------------------------------------------------------
-
-
 1 ;
+
+
+
+
+
+
+
+
+
