@@ -1,5 +1,6 @@
 
 package App::Asciio::stripes::process_box ;
+
 use base App::Asciio::stripes::stripes ;
 
 use strict;
@@ -8,8 +9,6 @@ use warnings;
 use List::Util qw(min max) ;
 use Readonly ;
 
-use App::Asciio::String ;
-
 #-----------------------------------------------------------------------------
 
 sub new
@@ -17,7 +16,7 @@ sub new
 my ($class, $element_definition) = @_ ;
 
 my $self = bless  {}, __PACKAGE__ ;
-
+	
 $self->setup
 	(
 	$element_definition->{TEXT_ONLY},
@@ -44,7 +43,6 @@ my @lines = split("\n", $text_only) ;
 @lines = ('')  unless @lines;
 
 my $number_of_lines = scalar(@lines) ;
-my $text_lines = $number_of_lines ;
 
 if($end_y - 3 > $number_of_lines)
 	{
@@ -64,12 +62,12 @@ my $current_half_the_lines = $half_the_lines ;
 my (@lines_width_plus_offset) ;
 for my $line (@lines)
 	{
-	push @lines_width_plus_offset, unicode_length($line) + abs($current_half_the_lines) ;
+	push @lines_width_plus_offset, length($line) + abs($current_half_the_lines) ;
 	$current_half_the_lines-- ;
 	}
 
 my $text_width_plus_offset  = max(@lines_width_plus_offset, $end_x) ;
-
+	
 my @top_lines = (splice @lines, 0, $number_of_lines / 2) ;
 
 my $center_line = shift @lines  || '' ;
@@ -80,7 +78,6 @@ push @bottom_lines, '' for (1 .. scalar(@top_lines) - scalar(@bottom_lines)) ;
 my (@stripes, $strip_text, $x_offset, $y_offset) ;
 
 $strip_text = '_' x (($text_width_plus_offset - 1) + $side_glyphs_size) . "\n\\" . ' ' x (($text_width_plus_offset - 2) + $side_glyphs_size) . "\\" ;
-
 push @stripes,
 	{
 	'HEIGHT' => 2,
@@ -89,7 +86,6 @@ push @stripes,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' =>0,
 	} ;
-
 $x_offset = 1 ;
 $y_offset = 2 ;
 
@@ -97,37 +93,35 @@ $current_half_the_lines = $half_the_lines ;
 for my $line (@top_lines)
 	{
 	my $front_padding = ' ' x $current_half_the_lines ;
-	my $padding = ' ' x ($text_width_plus_offset  - (unicode_length($line) + $current_half_the_lines)) ;
+	my $padding = ' ' x ($text_width_plus_offset  - (length($line) + $current_half_the_lines)) ;
 	my $strip_text = "\\ $front_padding$line$padding \\" ;
 	
 	push @stripes,
 		{
 		'HEIGHT' => 1,
 		'TEXT' => $strip_text,
-		'WIDTH' => unicode_length($strip_text),
+		'WIDTH' => length($strip_text),
 		'X_OFFSET' => $x_offset,
 		'Y_OFFSET' => $y_offset ,
 		} ;
-	
 	$x_offset++ ;
 	$y_offset++ ;
 	$current_half_the_lines-- ;
 	}
-
-my $padding = ' ' x ($text_width_plus_offset  - unicode_length($center_line)) ;
+	
+my $padding = ' ' x ($text_width_plus_offset  - length($center_line)) ;
 $strip_text = ') ' . $center_line . $padding . ' )' ;
-$element_width =  unicode_length($strip_text) + $y_offset - 1 ; # first stripe is two lines high, compensate offset by substracting one
+$element_width =  length($strip_text) + $y_offset - 1 ; # first stripe is two lines high, compensate offset by substracting one
 my $left_center_x = $y_offset - 2 ; # compensate as above and shft left
 
 push @stripes,
 	{
 	'HEIGHT' => 1,
 	'TEXT' => $strip_text,
-	'WIDTH' => unicode_length($strip_text),
+	'WIDTH' => length($strip_text),
 	'X_OFFSET' => $x_offset,
 	'Y_OFFSET' => $y_offset, 
 	};
-
 $y_offset++ ;
 $x_offset-- ;
 $current_half_the_lines = 1; 
@@ -135,7 +129,7 @@ $current_half_the_lines = 1;
 for my $line (@bottom_lines)
 	{
 	my $front_padding = ' ' x $current_half_the_lines ;
-	my $padding = ' ' x ($text_width_plus_offset  - (unicode_length($line) + $current_half_the_lines)) ;
+	my $padding = ' ' x ($text_width_plus_offset  - (length($line) + $current_half_the_lines)) ;
 	
 	my $strip_text = "/ $front_padding$line$padding /" ;
 	
@@ -143,7 +137,7 @@ for my $line (@bottom_lines)
 		{
 		'HEIGHT' => 1,
 		'TEXT' => $strip_text,
-		'WIDTH' => unicode_length($strip_text),
+		'WIDTH' => length($strip_text),
 		'X_OFFSET' => $x_offset,
 		'Y_OFFSET' => $y_offset ,
 		} ;
@@ -161,7 +155,7 @@ push @stripes,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => $y_offset, 
 	};
-
+	
 $self->set
 	(
 	STRIPES => \@stripes,
@@ -170,11 +164,8 @@ $self->set
 	LEFT_CENTER_X => $left_center_x,
 	RESIZE_POINT_X => $text_width_plus_offset + $side_glyphs_size - 1,
 	TEXT_ONLY => $text_only,
-	TEXT_BEGIN_X => int(($y_offset/2)+2),
-	TEXT_BEGIN_Y => int(($y_offset-$text_lines+2)/2),
 	EDITABLE => $editable,
 	RESIZABLE => $resizable,
-	EXTENTS => [0, 0, $element_width, $y_offset +  1],
 	) ;
 }
 
@@ -184,9 +175,16 @@ sub get_selection_action
 {
 my ($self, $x, $y) = @_ ;
 
-($x == $self->{RESIZE_POINT_X} && $y == $self->{HEIGHT} - 1)
-	? 'resize'
-	: 'move' ;
+if	(
+	($x == $self->{RESIZE_POINT_X} && $y == $self->{HEIGHT} - 1)
+	)
+	{
+	'resize' ;
+	}
+else
+	{
+	'move' ;
+	}
 }
 
 #-----------------------------------------------------------------------------
@@ -246,7 +244,10 @@ return
 sub get_extra_points
 {
 my ($self) = @_ ;
-return ( {X =>  $self->{RESIZE_POINT_X}, Y => $self->{HEIGHT} - 1 , NAME => 'resize'} ) ;
+return
+	(
+	{X =>  $self->{RESIZE_POINT_X}, Y => $self->{HEIGHT} - 1 , NAME => 'resize'},
+	) ;
 }
 
 #-----------------------------------------------------------------------------
@@ -298,7 +299,7 @@ if($new_end_x >= 0 &&  $new_end_y >= 0)
 		$self->{EDITABLE}, $self->{RESIZABLE}
 		) ;
 	}
-
+	
 return(0, 0, $self->{WIDTH}, $self->{HEIGHT}) ;
 }
 
@@ -318,7 +319,7 @@ my ($self, $text) = @_ ;
 $self->setup
 		(
 		$text,
-		$self->{RESIZE_POINT_X} - 3, # magic number are ugly
+		$self->{RESIZE_POINT_X} -	3, # magic number are ugly
 		$self->{HEIGHT} - 1,
 		$self->{EDITABLE}, $self->{RESIZABLE}
 		) ;
@@ -332,9 +333,9 @@ my ($self, $asciio) = @_ ;
 
 return unless $self->{EDITABLE} ;
 
-my ($text_only) = $asciio->display_edit_dialog('process object', $self->{TEXT_ONLY}, $asciio, $self->{X}, $self->{Y}, $self->{TEXT_BEGIN_X}, $self->{TEXT_BEGIN_Y}) ;
+my ($text_only) = $asciio->display_edit_dialog('asciio', $self->{TEXT_ONLY}) ;
 
-my $tab_as_space = $asciio->{TAB_AS_SPACES} ;
+my $tab_as_space = $self->{TAB_AS_SPACES} || (' ' x 3) ;
 $text_only =~ s/\t/$tab_as_space/g ;
 
 $self->set_text($text_only) ;
