@@ -13,25 +13,29 @@ use App::Asciio::stripes::wirl_arrow ;
 
 #-----------------------------------------------------------------------------
 
+# the idea is to reuse wirl arrow implementation as much as possible
+
+#-----------------------------------------------------------------------------
+
 Readonly my $DEFAULT_ARROW_TYPE =>
 			[
-			['origin',       '',  '*',   '',  '',  '', 1],
-			['up',          '|',  '|',   '',  '', '^', 1],
-			['down',        '|',  '|',   '',  '', 'v', 1],
-			['left',        '-',  '-',   '',  '', '<', 1],
-			['up-left',     '|',  '|',  '.', '-', '<', 1],
-			['left-up',     '-',  '-', '\'', '|', '^', 1],
-			['down-left',   '|',  '|', '\'', '-', '<', 1],
-			['left-down',   '-',  '-',  '.', '|', 'v', 1],
-			['right',       '-',  '-',   '',  '', '>', 1],
-			['up-right',    '|',  '|',  '.', '-', '>', 1],
-			['right-up',    '-',  '-', '\'', '|', '^', 1],
-			['down-right',  '|',  '|', '\'', '-', '>', 1],
-			['right-down',  '-',  '-',  '.', '|', 'v', 1],
-			['45',          '/',  '/',   '',  '', '^', 1],
-			['135',        '\\', '\\',   '',  '', 'v', 1],
-			['225',         '/',  '/',   '',  '', 'v', 1],
-			['315',        '\\', '\\',   '',  '', '^', 1],
+			['origin', '', '*', '', '', '', 1],
+			['up', '|', '|', '', '', '^', 1],
+			['down', '|', '|', '', '', 'v', 1],
+			['left', '-', '-', '', '', '<', 1],
+			['upleft', '|', '|', '.', '-', '<', 1],
+			['leftup', '-', '-', '\'', '|', '^', 1],
+			['downleft', '|', '|', '\'', '-', '<', 1],
+			['leftdown', '-', '-', '.', '|', 'v', 1],
+			['right', '-', '-','', '', '>', 1],
+			['upright', '|', '|', '.', '-', '>', 1],
+			['rightup', '-', '-', '\'', '|', '^', 1],
+			['downright', '|', '|', '\'', '-', '>', 1],
+			['rightdown', '-', '-', '.', '|', 'v', 1],
+			['45', '/', '/', '', '', '^', 1, ],
+			['135', '\\', '\\', '', '', 'v', 1, ],
+			['225', '/', '/', '', '', 'v', 1, ],
+			['315', '\\', '\\', '', '', '^', 1, ],
 			] ;
 
 # constants for connector overlays
@@ -42,17 +46,13 @@ Readonly my $up_index=> 1 ;
 Readonly my $left_index=> 3 ;
 Readonly my $leftup_index => 5 ;
 Readonly my $leftdown_index => 7 ;
-Readonly my $rightup_index => 10 ;
-Readonly my $rightdown_index => 12 ;
-
-#-----------------------------------------------------------------------------
 
 sub new
 {
 my ($class, $element_definition) = @_ ;
 
-my $self = bless {}, __PACKAGE__ ;
-
+my $self = bless  {}, __PACKAGE__ ;
+	
 $self->setup
 	(
 	$element_definition->{ARROW_TYPE} || Clone::clone($DEFAULT_ARROW_TYPE),
@@ -75,8 +75,6 @@ my ($self, $arrow_type, $points, $direction, $allow_diagonal_lines, $editable, $
 
 if('ARRAY' eq ref $points && @{$points} > 0)
 	{
-	delete $self->{CACHE} ;
-	
 	my ($start_x, $start_y, $arrows) = (0, 0, []) ;
 	
 	my $points_offsets ;
@@ -95,13 +93,13 @@ if('ARRAY' eq ref $points && @{$points} > 0)
 					ALLOW_DIAGONAL_LINES => $allow_diagonal_lines,
 					EDITABLE => $editable,
 					}) ;
-		
+						
 		$points_offsets->[$arrow_index++] = [$start_x, $start_y] ;
 		
 		push @{$arrows},  $arrow ;
 		($start_x, $start_y) = ($x, $y) ;
 		}
-	
+		
 	$self->set
 		(
 		POINTS_OFFSETS => $points_offsets,
@@ -115,7 +113,7 @@ if('ARRAY' eq ref $points && @{$points} > 0)
 		NOT_CONNECTABLE_START => $not_connectable_start,
 		NOT_CONNECTABLE_END => $not_connectable_end,
 		) ;
-	
+		
 	my ($width, $height) = $self->get_width_and_height() ;
 	$self->set
 			(
@@ -142,186 +140,139 @@ my %diagonal_non_diagonal_to_overlay_character =
 	(map {$_ => q{.}} qw( down-right right-down up-left left-up)), 
 	(map {$_ => q{'}} qw( down-left left-down up-right right-up)), 
 	) ;
-
-sub get_stripes
+	
+sub get_mask_and_element_stripes
 {
 my ($self) = @_ ;
 
-my $stripes = $self->{CACHE}{STRIPES} ;
+my @mask_and_element_stripes ;
 
-unless (defined $stripes)
+my $arrow_index = 0 ;
+for my $arrow(@{$self->{ARROWS}})
 	{
-	my @stripes ;
-	
-	my $arrow_index = 0 ;
-	for my $arrow(@{$self->{ARROWS}})
+	push @mask_and_element_stripes, 
+		map 
 		{
-		push @stripes, 
-			map 
-			{
-				{
-				TEXT     => $_->{TEXT},
-				WIDTH    => $_->{WIDTH}, 
-				HEIGHT   => $_->{HEIGHT} , 
-				X_OFFSET => $_->{X_OFFSET} + $self->{POINTS_OFFSETS}[$arrow_index][0],
-				Y_OFFSET => $_->{Y_OFFSET} + $self->{POINTS_OFFSETS}[$arrow_index][1],
-				}
-			} @{$arrow->get_stripes()} ;
-			
-		$arrow_index++ ;
-		}
-	
-	# handle connections
-	my ($previous_direction) = ($self->{ARROWS}[0]{DIRECTION} =~ /^([^-]+)/) ;
-	
-	my $previous_was_diagonal ;
-	
-	$arrow_index = 0 ;
-	for my $arrow(@{$self->{ARROWS}})
-		{
-		last if @{$self->{ARROWS}} == 1 ;
+		$_->{X_OFFSET} += $self->{POINTS_OFFSETS}[$arrow_index][0] ;
+		$_->{Y_OFFSET} += $self->{POINTS_OFFSETS}[$arrow_index][1];
+		$_ ;
+		} $arrow->get_mask_and_element_stripes() ;
 		
-		my ($connection, $d1, $d2) ;
-			
-		if($arrow->{DIRECTION} =~ /^([^-]+)-([^-]+)$/) 
+	$arrow_index++ ;
+	}
+
+# handle connections
+my ($previous_direction) = ($self->{ARROWS}[0]{DIRECTION} =~ /^([^-]+)/) ;
+
+my $previous_was_diagonal ;
+
+$arrow_index = 0 ;
+for my $arrow(@{$self->{ARROWS}})
+	{
+	last if @{$self->{ARROWS}} == 1 ;
+	
+	my ($connection, $d1, $d2) ;
+		
+	if($arrow->{DIRECTION} =~ /^([^-]+)-([^-]+)$/) 
+		{
+		($d1, $d2) = ($1, $2) ;
+		}
+	else
+		{
+		$d1 = $arrow->{DIRECTION};
+		}
+
+	if($self->{ALLOW_DIAGONAL_LINES} && $arrow->{WIDTH} == $arrow->{HEIGHT})
+		{
+		# this section is diagonal
+		if
+			(
+			$previous_was_diagonal
+			&& 
+				(
+				$previous_was_diagonal eq $arrow->{DIRECTION} 
+				|| 
+				(defined $d2 && $previous_was_diagonal eq "$d2-$d1")
+				)
+			)
 			{
-			($d1, $d2) = ($1, $2) ;
+			# two diagonals going in the same direction
+			$connection = $diagonal_direction_to_overlay_character{$arrow->{DIRECTION}} ;
 			}
 		else
 			{
-			$d1 = $arrow->{DIRECTION};
+			# previous non diagonal or two diagonals not going in the same direction
+			$connection  = ($d1 eq 'up' || (defined $d2 && $d2 eq 'up')) ?  q{'} : q{.} ;
 			}
-		
-		if($self->{ALLOW_DIAGONAL_LINES} && $arrow->{WIDTH} == $arrow->{HEIGHT})
+				
+		$previous_was_diagonal = $arrow->{DIRECTION} ;
+		}
+	else
+		{
+		# straight or angled arrow
+		if(defined $previous_was_diagonal)
 			{
-			# this section is diagonal
-			if
-				(
-				$previous_was_diagonal
-				&& 
-					(
-					$previous_was_diagonal eq $arrow->{DIRECTION} 
-					|| 
-					(defined $d2 && $previous_was_diagonal eq "$d2-$d1")
-					)
-				)
+			if($arrow->{DIRECTION} =~ /^down/)
 				{
-				# two diagonals going in the same direction
-				$connection = $diagonal_direction_to_overlay_character{$arrow->{DIRECTION}} ;
+				$connection = q{.}   ;
+				}
+			elsif($arrow->{DIRECTION} =~ /^up/)
+				{
+				$connection = q{'}  ;
 				}
 			else
 				{
-				# previous non diagonal or two diagonals not going in the same direction
-				$connection  = ($d1 eq 'up' || (defined $d2 && $d2 eq 'up')) ?  q{'} : q{.} ;
+				$connection = $previous_was_diagonal =~ /down/ ? q{'} : q{.} ;
 				}
-			
-			$previous_was_diagonal = $arrow->{DIRECTION} ;
 			}
 		else
 			{
-			# straight or angled arrow
-			if(defined $previous_was_diagonal)
+			if($previous_direction ne $d1)
 				{
-				if($arrow->{DIRECTION} =~ /^down/)
+				if($d1 eq 'down')
 					{
-					$connection = q{.}   ;
+					$connection = $self->{ARROW_TYPE}[$leftdown_index][$connection_index] ;
 					}
-				elsif($arrow->{DIRECTION} =~ /^up/)
+				elsif($d1 eq 'up')
 					{
-					$connection = q{'}  ;
+					$connection = $self->{ARROW_TYPE}[$leftup_index][$connection_index] ;
+					}
+				elsif($previous_direction eq 'down')
+					{
+					$connection = $self->{ARROW_TYPE}[$leftup_index][$connection_index] ;
+					}
+				elsif($previous_direction eq 'up')
+					{
+					$connection = $self->{ARROW_TYPE}[$leftdown_index][$connection_index] ;
 					}
 				else
 					{
-					$connection = $previous_was_diagonal =~ /down/ ? q{'} : q{.} ;
-					}
-				}
-			else
-				{
-				if($previous_direction ne $d1)
-					{
-					if($d1 eq 'down')
-						{
-						if($previous_direction eq 'right')
-							{
-							$connection = $self->{ARROW_TYPE}[$rightdown_index][$connection_index] ;
-							}
-						elsif($previous_direction eq 'left')
-							{
-							$connection = $self->{ARROW_TYPE}[$leftdown_index][$connection_index] ;
-							}
-						else
-							{
-							$connection = $self->{ARROW_TYPE}[$up_index][$connection_index] ;
-							}
-						}
-					elsif($d1 eq 'up')
-						{
-						if($previous_direction eq 'right')
-							{
-							$connection = $self->{ARROW_TYPE}[$rightup_index][$connection_index] ;
-							}
-						elsif($previous_direction eq 'left')
-							{
-							$connection = $self->{ARROW_TYPE}[$leftup_index][$connection_index] ;
-							}
-						else
-							{
-							$connection = $self->{ARROW_TYPE}[$up_index][$connection_index] ;
-							}
-						}
-					elsif($previous_direction eq 'down')
-						{
-						if($d1 eq 'left')
-							{
-							$connection = $self->{ARROW_TYPE}[$rightup_index][$connection_index] ;
-							}
-						else
-							{
-							$connection = $self->{ARROW_TYPE}[$leftup_index][$connection_index] ;
-							}
-						}
-					elsif($previous_direction eq 'up')
-						{
-						if($d1 eq 'left')
-							{
-							$connection = $self->{ARROW_TYPE}[$rightdown_index][$connection_index] ;
-							}
-						else
-							{
-							$connection = $self->{ARROW_TYPE}[$leftdown_index][$connection_index] ;
-							}
-						}
-					else
-						{
-						$connection = $self->{ARROW_TYPE}[$left_index][$body_index] ;
-						}
+					$connection = $self->{ARROW_TYPE}[$left_index][$body_index] ;  # for left and right, up down cases handled over
 					}
 				}
+			}
 			
-			$previous_direction = defined $d2 ? $d2 : $d1 ;
-			$previous_was_diagonal = undef ;
-			}
-		
-		if($arrow_index != 0 && defined $connection) # first character of the first section is always right
-			{
-			# overlay the first character of this arrow
-			push @stripes, 
-				{
-				TEXT     => $connection,
-				WIDTH    => 1,
-				HEIGHT   => 1,
-				X_OFFSET => $self->{POINTS_OFFSETS}[$arrow_index][0],
-				Y_OFFSET => $self->{POINTS_OFFSETS}[$arrow_index][1],
-				} ;
-			}
-		
-		$arrow_index++ ;
+		$previous_direction = defined $d2 ? $d2 : $d1 ;
+		$previous_was_diagonal = undef ;
 		}
-	
-	$stripes = $self->{CACHE}{STRIPES} = \@stripes ;
+		
+	if($arrow_index != 0 && defined $connection) # first character of the first section is always right
+		{
+		# overlay the first character of this arrow
+		push @mask_and_element_stripes, 
+			{
+			X_OFFSET => $self->{POINTS_OFFSETS}[$arrow_index][0],
+			Y_OFFSET => $self->{POINTS_OFFSETS}[$arrow_index][1],
+			WIDTH => 1,
+			HEIGHT => 1,
+			TEXT => $connection,
+			} ;
+		}
+		
+	$arrow_index++ ;
 	}
 
-return $stripes ;
+return(@mask_and_element_stripes) ;
 }
 
 #-----------------------------------------------------------------------------
@@ -339,13 +290,13 @@ for my $arrow(@{$self->{ARROWS}})
 	
 	$start_connector->{X} += $self->{POINTS_OFFSETS}[$arrow_index][0] ;
 	$start_connector->{Y} += $self->{POINTS_OFFSETS}[$arrow_index][1] ;
-	
+		
 	if($x == $start_connector->{X} && $y == $start_connector->{Y})
 		{
 		$action = 'resize' ;
 		last ;
 		}
-	
+		
 	$end_connector->{X} += $self->{POINTS_OFFSETS}[$arrow_index][0] ;
 	$end_connector->{Y} += $self->{POINTS_OFFSETS}[$arrow_index][1] ;
 	
@@ -354,7 +305,7 @@ for my $arrow(@{$self->{ARROWS}})
 		$action = 'resize' ;
 		last ;
 		}
-	
+		
 	$arrow_index++ ;
 	}
 
@@ -420,8 +371,8 @@ sub get_connector_points
 {
 my ($self) = @_ ;
 
-my (@all_connector_points)  = $self->get_all_points() ;
-my (@connector_points) ;
+my(@all_connector_points)  = $self->get_all_points() ;
+my(@connector_points) ;
 
 push @connector_points, $all_connector_points[0] unless $self->{NOT_CONNECTABLE_START} ;
 push @connector_points, $all_connector_points[-1] unless $self->{NOT_CONNECTABLE_END} ;
@@ -429,8 +380,6 @@ push @connector_points, $all_connector_points[-1] unless $self->{NOT_CONNECTABLE
 return(@connector_points) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_extra_points
 {
 my ($self) = @_ ;
@@ -439,12 +388,10 @@ my(@all_connector_points)  = $self->get_all_points() ;
 
 shift @all_connector_points unless $self->{NOT_CONNECTABLE_START} ;
 pop @all_connector_points  unless $self->{NOT_CONNECTABLE_END} ;
-
+	
 return(@all_connector_points) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_all_points
 {
 my ($self) = @_ ;
@@ -500,16 +447,10 @@ for my $arrow(@{$self->{ARROWS}})
 			$start_connector->{X} += $self->{POINTS_OFFSETS}[$arrow_index][0] ;
 			$start_connector->{Y} += $self->{POINTS_OFFSETS}[$arrow_index][1] ;
 			$connection = $start_connector ;
-			
-			for my $arrow_type (@{$arrow->{ARROW_TYPE}})
-				{
-				$connection->{CHAR} = $arrow_type->[1] and last if $arrow->{DIRECTION} eq $arrow_type->[0] ;
-				}
-			
 			last ;
 			}
 		}
-	
+		
 	$end_connector->{NAME} .= "section_$arrow_index" ;
 	
 	if($name eq  $end_connector->{NAME})
@@ -517,15 +458,9 @@ for my $arrow(@{$self->{ARROWS}})
 		$end_connector->{X} += $self->{POINTS_OFFSETS}[$arrow_index][0] ;
 		$end_connector->{Y} += $self->{POINTS_OFFSETS}[$arrow_index][1] ;
 		$connection = $end_connector ;
-		
-		for my $arrow_type (@{$arrow->{ARROW_TYPE}})
-			{
-			$connection->{CHAR} = $arrow_type->[5] and last if $arrow->{DIRECTION} eq $arrow_type->[0] ;
-			}
-		
 		last ;
 		}
-	
+		
 	$arrow_index++ ;
 	}
 
@@ -544,8 +479,6 @@ my $connection = $self->get_named_connection($connector_name) ;
 
 if($connection)
 	{
-	delete $self->{CACHE} ;
-	
 	my ($x_offset, $y_offset, $width, $height, undef) = 
 		$self->resize
 			(
@@ -557,7 +490,7 @@ if($connection)
 			#~ [$no_section_connetor_name, $connector_name],
 			[$connector_name, $no_section_connetor_name],
 			) ;
-	
+		
 	return
 		(
 		$x_offset, $y_offset, $width, $height,
@@ -579,8 +512,6 @@ my ($self, $reference_x, $reference_y, $new_x, $new_y, $hint, $connector_name_ar
 Readonly my $MULTI_WIRL_CONNECTOR_NAME_INDEX => 0 ;
 Readonly my $WIRL_CONNECTOR_NAME_INDEX => 1 ;
 
-delete $self->{CACHE} ;
-
 my ($start_element, $start_element_index, $end_element, $end_element_index) ;
 
 # find elements connected by the connector
@@ -617,7 +548,7 @@ if(defined $start_element)
 			$is_start++  ;
 			}
 		}
-	
+
 	if($is_start)
 		{
 		#~ print "Moving start connector\n" ;
@@ -674,7 +605,7 @@ if(defined $start_element)
 			}
 		}
 	}
-
+	
 my ($width, $height) = $self->get_width_and_height() ;
 $self->set(WIDTH => $width, HEIGHT => $height) ;
 
@@ -684,7 +615,7 @@ return($start_x_offset, $start_y_offset, $width, $height, $connector_name_array)
 sub find_elements_for_connector_at
 {
 my ($self, $reference_x, $reference_y) = @_ ;
-
+	
 my ($start_element, $start_element_index, $end_element, $end_element_index, $connector_name, $wirl_connector_name) ;
 
 my $arrow_index = 0 ;
@@ -699,13 +630,13 @@ for my $arrow(@{$self->{ARROWS}})
 		$connector_name =  $wirl_connector_name . "section_$arrow_index" ;
 		last ;
 		}
-	
+		
 	if(defined $start_element)
 		{
 		($end_element, $end_element_index) = ($arrow, $arrow_index) ;
 		last ;
 		}
-	
+		
 	if
 		(
 		   $reference_x == $end_connector->{X} + $self->{POINTS_OFFSETS}[$arrow_index][0]
@@ -716,7 +647,7 @@ for my $arrow(@{$self->{ARROWS}})
 		$wirl_connector_name = $end_connector->{NAME} ;
 		$connector_name =  $wirl_connector_name . "section_$arrow_index" ;
 		}
-	
+		
 	$arrow_index++ ;
 	}
 
@@ -741,27 +672,32 @@ for my $arrow(@{$self->{ARROWS}})
 		($start_element, $start_element_index) = ($arrow, $arrow_index) ;
 		last ;
 		}
-	
+		
 	if(defined $start_element)
 		{
 		($end_element, $end_element_index) = ($arrow, $arrow_index) ;
 		last ;
 		}
-	
+		
 	if($connector_name eq $end_connector->{NAME} . "section_$arrow_index")
 		{
 		($start_element, $start_element_index) = ($arrow, $arrow_index) ;
 		}
-	
+		
 	$arrow_index++ ;
 	}
-
+	
 return($start_element, $start_element_index, $end_element, $end_element_index, $connector_name_array) ;
 }
 
 #-----------------------------------------------------------------------------
 
-sub get_number_of_sections { my ($self) = @_ ; return scalar(@{$self->{ARROWS}}) ; }
+sub get_number_of_sections
+{
+my ($self) = @_ ;
+
+return scalar(@{$self->{ARROWS}}) ;
+}
 
 #-----------------------------------------------------------------------------
 
@@ -785,8 +721,6 @@ sub insert_section
 {
 my ($self, $x_offset, $y_offset) = @_ ;
 
-delete $self->{CACHE} ;
-
 my $index = 0 ;
 
 for my $arrow (@{$self->{ARROWS}})
@@ -812,7 +746,7 @@ for my $arrow (@{$self->{ARROWS}})
 					ALLOW_DIAGONAL_LINES => $arrow->{ALLOW_DIAGONAL_LINES},
 					EDITABLE => $arrow->{EDITABLE},
 					}) ;
-		
+			
 		$self->{ARROWS}[$index] = $first_section ;
 		
 		my $new_section = new App::Asciio::stripes::wirl_arrow
@@ -827,10 +761,10 @@ for my $arrow (@{$self->{ARROWS}})
 					
 		splice @{$self->{ARROWS}}, $index + 1, 0, $new_section ;
 		splice @{$self->{POINTS_OFFSETS}}, $index + 1, 0, [$x_offset, $y_offset] ;
-		
+
 		last ;
 		}
-	
+		
 	$index++ ;
 	}
 }
@@ -841,8 +775,6 @@ sub prepend_section
 {
 my ($self, $extend_x, $extend_y) = @_ ;
 
-delete $self->{CACHE} ;
-
 my $arrow = new App::Asciio::stripes::wirl_arrow
 			({
 			END_X => -$extend_x, 
@@ -861,7 +793,7 @@ for my $arrow(@{$self->{ARROWS}})
 	
 	$arrow_index++ ;
 	}
-
+	
 unshift @{$self->{POINTS_OFFSETS}}, [0, 0] ;
 unshift @{$self->{ARROWS}}, $arrow ;
 
@@ -869,14 +801,10 @@ my ($width, $height) = $self->get_width_and_height() ;
 $self->set(WIDTH => $width, HEIGHT => $height,) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub append_section
 {
 my ($self, $extend_x, $extend_y) = @_ ;
 
-delete $self->{CACHE} ;
-
 my $last_point = $self->get_points()->[-1] ;
 
 my $arrow = new App::Asciio::stripes::wirl_arrow
@@ -897,7 +825,7 @@ $start_y += $end_connector->{Y} ;
 
 push @{$self->{POINTS_OFFSETS}}, [$start_x, $start_y] ;
 push @{$self->{ARROWS}}, $arrow ;
-
+		
 my ($width, $height) = $self->get_width_and_height() ;
 $self->set(WIDTH => $width, HEIGHT => $height,) ;
 }
@@ -910,11 +838,9 @@ my ($self) = @_ ;
 
 return if @{$self->{ARROWS}} == 1 ;
 
-delete $self->{CACHE} ;
-
 pop @{$self->{POINTS_OFFSETS}} ;
 pop @{$self->{ARROWS}} ;
-
+		
 my ($width, $height) = $self->get_width_and_height() ;
 $self->set(WIDTH => $width, HEIGHT => $height,) ;
 }
@@ -927,14 +853,12 @@ my ($self) = @_ ;
 
 return(0, 0) if @{$self->{ARROWS}} == 1 ;
 
-delete $self->{CACHE} ;
-
 my $second_arrow_x_offset = $self->{POINTS_OFFSETS}[1][0] ;
 my $second_arrow_y_offset = $self->{POINTS_OFFSETS}[1][1] ;
 
 shift @{$self->{POINTS_OFFSETS}} ;
 shift @{$self->{ARROWS}} ;
-
+		
 my $arrow_index = 0 ;
 for my $arrow(@{$self->{ARROWS}})
 	{
@@ -943,7 +867,7 @@ for my $arrow(@{$self->{ARROWS}})
 	
 	$arrow_index++ ;
 	}
-
+	
 my ($width, $height) = $self->get_width_and_height() ;
 $self->set(WIDTH => $width, HEIGHT => $height,) ;
 
@@ -956,8 +880,6 @@ sub change_section_direction
 {
 my ($self, $x, $y) = @_ ;
 
-delete $self->{CACHE} ;
-
 if(1 == @{$self->{ARROWS}})
 	{
 	my $direction = $self->{ARROWS}[0]->get_direction() ;
@@ -970,7 +892,7 @@ if(1 == @{$self->{ARROWS}})
 else
 	{
 	my $index = 0 ;
-	
+
 	for my $arrow(@{$self->{ARROWS}})
 		{
 		if
@@ -992,56 +914,41 @@ else
 				
 			last ;
 			}
-		
+			
 		$index++ ;
 		}
 	}
 }
 
-#-----------------------------------------------------------------------------
-
-sub change_last_section_direction
-{
-my ($self, $x, $y) = @_ ;
-
-delete $self->{CACHE} ;
-
-my $direction = $self->{ARROWS}[-1]->get_direction() ;
-
-if($direction =~ /(.*)-(.*)/)
-	{
-	$self->{ARROWS}[-1]->resize(0, 0, 0, 0, "$2-$1") ;
-	}
-}
-
-#-----------------------------------------------------------------------------
-
 sub is_over_element
 {
 my ($self, $element, $x, $y, $field, $element_offset_x, $element_offset_y, ) = @_ ;
 
+die "Error: 'is_over_element' needs position!" unless defined $x && defined $y ;
+
 $field ||= 0 ;
 my $is_under = 0 ;
 
-for my $strip (@{$element->get_stripes()})
+for my $mask_strip ($element->get_mask_and_element_stripes())
 	{
-	my $stripe_x = $element_offset_x + $strip->{X_OFFSET} ;
-	my $stripe_y = $element_offset_y + $strip->{Y_OFFSET} ;
+	my $stripe_x = $element_offset_x + $mask_strip->{X_OFFSET} ;
+	my $stripe_y = $element_offset_y + $mask_strip->{Y_OFFSET} ;
 	
 	if
 		(
-		$stripe_x - $field <= $x   && $x < $stripe_x + $strip->{WIDTH} + $field
-		&& $stripe_y - $field <= $y && $y < $stripe_y + $strip->{HEIGHT} + $field
+		$stripe_x - $field <= $x   && $x < $stripe_x + $mask_strip->{WIDTH} + $field
+		&& $stripe_y - $field <= $y && $y < $stripe_y + $mask_strip->{HEIGHT} + $field
 		) 
 		{
 		$is_under++ ;
 		last ;
 		}
 	}
-
+	
 return($is_under) ;
 }
 
+
 #-----------------------------------------------------------------------------
 
 sub get_width_and_height
@@ -1067,22 +974,22 @@ for my $start_point (@{$self->{POINTS_OFFSETS}})
 	$arrow_index++ ;
 	}
 
-$self->{EXTENTS} = [$smallest_x, $smallest_y, $biggest_x + 1, $biggest_y + 1] ;
-
 return(($biggest_x - $smallest_x) + 1, ($biggest_y - $smallest_y) + 1) ;
 }
 
 #-----------------------------------------------------------------------------
 
-sub get_arrow_type { my ($self) = @_ ; return($self->{ARROW_TYPE})  ; }
+sub get_arrow_type
+{
+my ($self) = @_ ;
+return($self->{ARROW_TYPE})  ;
+}
 
 #-----------------------------------------------------------------------------
 
 sub set_arrow_type
 {
 my ($self, $arrow_type) = @_ ;
-
-delete $self->{CACHE} ;
 $self->setup($arrow_type, $self->get_points(), $self->{DIRECTION}, $self->{ALLOW_DIAGONAL_LINES}, $self->{EDITABLE}) ;
 }
 
@@ -1120,12 +1027,21 @@ my ($self) = @_ ;
 
 return unless $self->{EDITABLE} ;
 
-delete $self->{CACHE} ;
+# add section
+# remove section
 
-$self->display_arrow_edit_dialog() ;
+# handle offset array
 }
 
 #-----------------------------------------------------------------------------
 
 1 ;
 
+
+
+
+
+
+
+
+
