@@ -16,23 +16,23 @@ Readonly my $DEFAULT_ARROW_TYPE =>
 	[
 	#name: $start, $body, $connection, $body_2, $end
 	
-	['origin',       '',  '*',   '',  '',  '', 1],
-	['up',          '|',  '|',   '',  '', '^', 1],
-	['down',        '|',  '|',   '',  '', 'v', 1],
-	['left',        '-',  '-',   '',  '', '<', 1],
-	['up-left',     '|',  '|',  '.', '-', '<', 1],
-	['left-up',     '-',  '-', '\'', '|', '^', 1],
-	['down-left',   '|',  '|', '\'', '-', '<', 1],
-	['left-down',   '-',  '-',  '.', '|', 'v', 1],
-	['right',       '-',  '-',   '',  '', '>', 1],
-	['up-right',    '|',  '|',  '.', '-', '>', 1],
-	['right-up',    '-',  '-', '\'', '|', '^', 1],
-	['down-right',  '|',  '|', '\'', '-', '>', 1],
-	['right-down',  '-',  '-',  '.', '|', 'v', 1],
-	['45',          '/',  '/',   '',  '', '^', 1],
-	['135',        '\\', '\\',   '',  '', 'v', 1],
-	['225',        ' /',  '/',   '',  '', 'v', 1],
-	['315',        '\\', '\\',   '',  '', '^', 1],
+	['origin', '', '*', '', '', '', 1],
+	['up', '|', '|', '', '', '^', 1],
+	['down', '|', '|', '', '', 'v', 1],
+	['left', '-', '-', '', '', '<', 1],
+	['upleft', '|', '|', '.', '-', '<', 1],
+	['leftup', '-', '-', '\'', '|', '^', 1],
+	['downleft', '|', '|', '\'', '-', '<', 1],
+	['leftdown', '-', '-', '.', '|', 'v', 1],
+	['right', '-', '-','', '', '>', 1],
+	['upright', '|', '|', '.', '-', '>', 1],
+	['rightup', '-', '-', '\'', '|', '^', 1],
+	['downright', '|', '|', '\'', '-', '>', 1],
+	['rightdown', '-', '-', '.', '|', 'v', 1],
+	['45', '/', '/', '', '', '^', 1, ],
+	['135', '\\', '\\', '', '', 'v', 1, ],
+	['225', '/', '/', '', '', 'v', 1, ],
+	['315', '\\', '\\', '', '', '^', 1, ],
 	] ;
 
 sub new
@@ -40,7 +40,7 @@ sub new
 my ($class, $element_definition) = @_ ;
 
 my $self = bless  {}, __PACKAGE__ ;
-
+	
 $self->setup
 	(
 	$element_definition->{ARROW_TYPE} || Clone::clone($DEFAULT_ARROW_TYPE),
@@ -94,7 +94,7 @@ my %direction_to_arrow =
 	'down-right' => \&draw_downright,
 	'right-down' => \&draw_rightdown,
 	) ;
-
+	
 sub get_arrow
 {
 my ($arrow_type, $end_x, $end_y, $direction, $allow_diagonal_lines) = @_ ;
@@ -113,14 +113,12 @@ my @position_to_direction =
 	) ;
 
 $direction = $position_to_direction
-		[$end_x == 0 ? CENTER : $end_x < 0 ? LEFT : RIGHT]
-		[$end_y == 0 ? CENTER : $end_y < 0 ? UP : DOWN] ;
+			[$end_x == 0 ? CENTER : $end_x < 0 ? LEFT : RIGHT]
+			[$end_y == 0 ? CENTER : $end_y < 0 ? UP : DOWN] ;
 
 return($direction_to_arrow{$direction}->($arrow_type, $end_x, $end_y, $allow_diagonal_lines), $direction) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_down
 {
 my ($arrow_type, $end_x, $end_y) = @_ ;
@@ -135,13 +133,11 @@ push @{$stripes},
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_origin
 {
 my ($arrow_type, $end_x, $end_y) = @_ ;
@@ -156,13 +152,11 @@ push @{$stripes},
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 } 
 
-#-----------------------------------------------------------------------------
-
 sub draw_up
 {
 my ($arrow_type, $end_x, $end_y) = @_ ;
@@ -177,13 +171,11 @@ push @{$stripes},
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => $end_y, 
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_left
 {
 my ($arrow_type, $end_x, $end_y) = @_ ;
@@ -198,13 +190,11 @@ push @{$stripes},
 	'WIDTH' => $width,
 	'X_OFFSET' => $end_x,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_upleft # or 315
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -233,14 +223,12 @@ else
 		'WIDTH' => $width - 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $end_y ,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_leftup # or 315
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -269,14 +257,12 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $end_y ,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_315_stripes
 {
 my ($position, $start, $body, $end) = @_ ;
@@ -290,7 +276,7 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
+	};
 	
 for(my $xy = -$position - 1 ; $xy> 0 ; $xy--)
 	{
@@ -301,9 +287,9 @@ for(my $xy = -$position - 1 ; $xy> 0 ; $xy--)
 		'WIDTH' => 1,
 		'X_OFFSET' => -$xy,
 		'Y_OFFSET' => -$xy,
-		} ;
+		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -311,13 +297,11 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => $position ,
 	'Y_OFFSET' => $position ,
-	} ;
-
+	};
+	
 return(@stripes) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_downleft # or 225
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -346,14 +330,12 @@ else
 		'WIDTH' => $width - 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $end_y ,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_leftdown # or 225
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -382,14 +364,12 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => 1 ,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_225_stripes
 {
 my ($position, $start, $body, $end) = @_ ;
@@ -403,8 +383,8 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 for(my $xy = -$position - 1 ; $xy> 0 ; $xy--)
 	{
 	push @stripes,
@@ -414,9 +394,9 @@ for(my $xy = -$position - 1 ; $xy> 0 ; $xy--)
 		'WIDTH' => 1,
 		'X_OFFSET' => -$xy,
 		'Y_OFFSET' => $xy,
-		} ;
+		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -424,13 +404,11 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => $position ,
 	'Y_OFFSET' => -$position ,
-	} ;
-
+	};
+	
 return(@stripes) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_right
 {
 my ($arrow_type, $end_x, $end_y) = @_ ;
@@ -445,13 +423,11 @@ push @{$stripes},
 	'WIDTH' => $width,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_upright # or 45
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -480,14 +456,12 @@ else
 		'WIDTH' => $end_x,
 		'X_OFFSET' => 1,
 		'Y_OFFSET' => $end_y,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_rightup # or 45
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -516,14 +490,12 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => $end_y,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_45_stripes
 {
 my ($position, $start, $body, $end) = @_ ;
@@ -537,8 +509,8 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0,
 	'Y_OFFSET' => 0,
-	} ;
-
+	};
+	
 for(my $xy = $position - 1 ; $xy > 0 ; $xy--)
 	{
 	push @stripes,
@@ -548,9 +520,9 @@ for(my $xy = $position - 1 ; $xy > 0 ; $xy--)
 		'WIDTH' => 1,
 		'X_OFFSET' => $xy,
 		'Y_OFFSET' => -$xy,
-		} ;
+		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -558,13 +530,11 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => $position ,
 	'Y_OFFSET' => -$position ,
-	} ;
-
+	};
+			
 return(@stripes) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_downright # or 135
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -593,14 +563,12 @@ else
 		'WIDTH' => $width - 1,
 		'X_OFFSET' => 1,
 		'Y_OFFSET' => $end_y,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub draw_rightdown # or 135
 {
 my ($arrow_type, $end_x, $end_y, $allow_diagonal_lines) = @_ ;
@@ -629,14 +597,12 @@ else
 		'WIDTH' => 1,
 		'X_OFFSET' => $end_x,
 		'Y_OFFSET' => 1,
-		} ;
+		};
 	}
-
+	
 return($stripes, $width, $height) ;
 }
 
-#-----------------------------------------------------------------------------
-
 sub get_135_stripes
 {
 my ($position, $start, $body, $end) = @_ ;
@@ -650,8 +616,8 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => 0 ,
 	'Y_OFFSET' => 0 ,
-	} ;
-
+	};
+	
 for(my $xy = 1 ; $xy < $position ; $xy++)
 	{
 	push @stripes,
@@ -661,9 +627,9 @@ for(my $xy = 1 ; $xy < $position ; $xy++)
 		'WIDTH' => 1,
 		'X_OFFSET' => $xy,
 		'Y_OFFSET' => $xy,
-		} ;
+		};
 	}
-
+	
 push @stripes,
 	{
 	'HEIGHT' => 1,
@@ -671,7 +637,7 @@ push @stripes,
 	'WIDTH' => 1,
 	'X_OFFSET' => $position,
 	'Y_OFFSET' => $position,
-	} ;
+	};
 
 return(@stripes) ;
 }
@@ -715,11 +681,11 @@ my ($self, $name) = @_ ;
 
 if($name eq 'start')
 	{
-	return( {X => 0, Y => 0, NAME => 'start', CHAR => 'X'} ) ;
+	return( {X => 0, Y => 0, NAME => 'start'} ) ;
 	}
 elsif($name eq 'end')
 	{
-	return( {X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end', CHAR => 'Y'} ) ;
+	return( {X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end'} ) ;
 	}
 else
 	{
@@ -755,7 +721,7 @@ elsif($connector_name eq 'end')
 	{
 	my ($x_offset, $y_offset, $width, $height, undef) = 
 		$self->resize(-1, -1, $self->{END_X} + $x_offset, $self->{END_Y} + $y_offset, $hint) ;
-	
+
 	return 
 		$x_offset, $y_offset, $width, $height,
 		{X => $self->{END_X}, Y => $self->{END_Y}, NAME => 'end'} ;
@@ -798,16 +764,16 @@ if($is_start)
 	my $new_end_y = $self->{END_Y} - $y_offset ;
 	
 	$self->setup($self->{ARROW_TYPE}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION},$self ->{ALLOW_DIAGONAL_LINES}, $self->{EDITABLE}) ;
-	
+
 	return($x_offset, $y_offset, $self->{WIDTH}, $self->{HEIGHT}, 'start') ;
 	}
 else
 	{
 	my $new_end_x = $new_x ;
 	my $new_end_y = $new_y ;
-	
+
 	$self->setup($self->{ARROW_TYPE}, $new_end_x, $new_end_y, $hint || $self->{DIRECTION}, $self ->{ALLOW_DIAGONAL_LINES}, $self->{EDITABLE}) ;
-	
+
 	return(0, 0, $self->{WIDTH}, $self->{HEIGHT}, 'end') ;
 	}
 }
