@@ -26,9 +26,9 @@ my ($self, $event) = @_ ;
 
 $self->create_undo_snapshot() ;
 
-if($event->button == 1) 
+if($event->{BUTTON} == 1) 
 	{
-	my ($x, $y) = $self->closest_character($event->coords()) ;
+	my ($x, $y) = @{$event->{COORDINATES}} ;
 	my ($destination_element) = first_value {$self->is_over_element($_, $x, $y)} reverse @{$self->{ELEMENTS}} ;
 	
 	if($destination_element)
@@ -76,7 +76,7 @@ if(@destination_connections)
 	
 	if(@selected_elements)
 		{
-		$self->select_elements(0, @{$self->{ELEMENTS}}) ;
+		$self->deselect_all_elements() ;
 		
 		for my $element (@selected_elements)
 			{
@@ -169,7 +169,6 @@ for(grep {$_->{CONNECTED} == $element } @{$self->{CONNECTIONS}})
 
 my ($unconnected_connector_name) = reverse sort keys %source_connectors ;
 
-print "$unconnected_connector_name\n" ;
 if($unconnected_connector_name)
 	{
 	my $unconnected_connector = $source_connectors{$unconnected_connector_name} ;
