@@ -1,20 +1,26 @@
 
+use strict ;
+use warnings ;
+
 #----------------------------------------------------------------------------------------------
 
 register_action_handlers
 	(
-	'Create multiple box elements from a text description' => ['C00-m', \&insert_multiple_boxes_from_text_description],
-	'Create multiple text elements from a text description' => ['C0S-M', \&insert_multiple_texts_from_text_description],
+	'Create multiple box elements from a text description' => ['C00-m', \&insert_multiple_boxes_from_text_description, 1],
+	'Create multiple text elements from a text description' => ['C0S-M', \&insert_multiple_boxes_from_text_description, 0],
 	'Flip transparent element background' => ['C00-t', \&transparent_elements],
 	'Flip grid display' => ['000-g', \&flip_grid_display],
+	'Flip color scheme' => ['CA0-c', \&flip_color_scheme],
 	'Undo' => ['C00-z', \&undo],
 	'Display undo stack statistics' => ['C0S-Z', \&display_undo_stack_statistics],
 	'Redo' => ['C00-y', \&redo],
 	'Display keyboard mapping' => ['000-k', \&display_keyboard_mapping],
 	'Display commands' => ['C00-k', \&display_commands],
 	'Display action files' => ['C0S-K', \&display_action_files],
-	'Zoom in' => ['000-KP_Add', \&zoom, 2],
-	'Zoom out' => ['000-KP_Subtract', \&zoom, -2],
+	'Zoom in' => ['000-KP_Add', \&zoom, 1],
+	'Zoom out' => ['000-minus', \&zoom, -1],
+	'Zoom in' => ['000-plus', \&zoom, 1],
+	'Zoom out' => ['000-KP_Subtract', \&zoom, -1],
 	'Help' => ['000-F1', \&display_help],
 	'External command output in a box' => ['000-x', \&external_command_output, 1],
 	'External command output in a box no frame' => ['C00-x', \&external_command_output, 0],
@@ -29,33 +35,36 @@ my ($self) = @_ ;
 
 $self->display_message_modal(<<EOM) ;
 
-Some very short help.
+Very short help:
 
-k shows you all the keyboard mapping.
+k show the keyboard mapping
+CTL+SHIFT+k 
 	
 b, Add a box
 B, Add a box, edit the text directly
-t, Add a text element
-a, add a wirl arrow (AsciiO arrow)
+CTL+m, Add multiple boxes in one shot
 
-copy elements with the CTL key
-add elements to the selection with shift
+t, Add a text element
+CTL+SHIFT+M, Add multiple texts in one shot
 
 quick link:
 	select a box
 	CTL+SHIFT+ left mouse on the other element
 	
+a, add a wirl arrow (AsciiO arrow)
+SHIFT+A, add an angled arrow
 d, change the direction of the arrows (selection)
 f, flip the arrows (selection)
 
-CTL+m, Add multiple box in one shot
-CTL+t, Add multiple boxes in one shot
+
+CTL+click, copy elements
+SHIFT+click: add elements to the selection
 
 CTL+g, group elements
 CTL+u, ungroup object
 
 Mouse right button shows a context menu.
-Double click (may) shows the element editing dialog
+Double click shows the element editing dialog
 
 EOM
 }
@@ -73,6 +82,81 @@ $self->set_font($family, $size + $direction) ;
 
 #----------------------------------------------------------------------------------------------
 
+sub flip_color_scheme
+{
+my ($self) = @_ ;
+
+$self->{COLOR_SCHEME} = 'system' unless exists $self->{COLOR_SCHEME} ;
+
+if($self->{COLOR_SCHEME} eq 'system')
+	{
+	$self->flush_color_cache() ;
+	$self->{COLOR_SCHEME} = 'linux' ;
+	$self->{COLORS} =
+		{
+		background => [10, 10, 10],
+		grid => [30, 30, 30],
+		ruler_line => [25, 60, 80],
+		selected_element_background => [25, 40, 50],
+		element_background => [25, 25, 25],
+		element_foreground => [150, 150, 150] ,
+		selection_rectangle => [110, 0, 110],
+		test => [0, 255, 255],
+		group_colors =>
+			[
+			[[0x41, 0x32, 0x23], [0x2B, 0x21, 0x17]],
+			[[0x21, 0x3C, 0x23], [0x15, 0x27, 0x17]],
+			[[0x23, 0x32, 0x3C], [0x18, 0x22, 0x29]],
+			[[0x10, 0x44, 0x44], [0x0A, 0x2C, 0x2C]],
+			[[0x50, 0x28, 0x20], [0x2E, 0x17, 0x13]],
+			],
+			
+		connection => [140, 65, 20],
+		connection_point => [130, 100, 50],
+		connector_point => [20, 100, 155],
+		new_connection => [180, 0, 0],
+		extra_point => [150, 110, 50], 
+		} ;
+		
+	$self->update_display() ;
+	}
+else
+	{
+	$self->flush_color_cache() ;
+	$self->{COLOR_SCHEME} = 'system' ;
+	$self->{COLORS} =
+		{
+		background => [255, 255, 255],
+		grid => [229, 235, 255],
+		ruler_line => [85, 155, 225],
+		selected_element_background => [180, 244, 255],
+		element_background => [251, 251, 254],
+		element_foreground => [0, 0, 0] ,
+		selection_rectangle => [255, 0, 255],
+		test => [0, 255, 255],
+		
+		group_colors =>
+			[
+			[[250, 221, 190], [250, 245, 239]],
+			[[182, 250, 182], [241, 250, 241]],
+			[[185, 219, 250], [244, 247, 250]],
+			[[137, 250, 250], [235, 250, 250]],
+			[[198, 229, 198], [239, 243, 239]],
+			],
+			
+		connection => 'Chocolate',
+		connection_point => [230, 198, 133],
+		connector_point => 'DodgerBlue',
+		new_connection => 'red' ,
+		extra_point => [230, 198, 133],
+		} ;
+
+	$self->update_display() ;
+	}
+}
+
+#----------------------------------------------------------------------------------------------
+
 sub display_keyboard_mapping
 {
 my ($self) = @_ ;
@@ -290,22 +374,6 @@ for my $action (keys %{$key_mapping})
 
 #----------------------------------------------------------------------------------------------
 
-sub code_to_key
-{
-my ($modifier_and_code) = @_ ;
-
-use Gtk2::Gdk::Keysyms ;
-my %K = %Gtk2::Gdk::Keysyms ;
-my %C = map{$K{$_} => $_} keys %K ;
-
-my($modifier, $code) = $modifier_and_code=~ /^(...)(.*)/ ;
-my $key = $C{$code} || $code ;
-
-"$modifier-$key" ;
-}
-
-#----------------------------------------------------------------------------------------------
-
 sub undo
 {
 my ($self) = @_ ;
@@ -348,19 +416,21 @@ $self->show_dump_window($statistics, 'Undo stack statistics:') ;
 
 sub insert_multiple_boxes_from_text_description
 {
-my ($self) = @_ ;
+my ($self, $boxed) = @_ ;
 
-$self->create_undo_snapshot() ;
-
-my $text = $self->display_edit_dialog('multiple boxes from input', "--\nA\n--\nB\n--\nC\n--\nD\n--\nE\n" ) ;
+my $text = $self->display_edit_dialog('multiple texts from input', "\ntext\ntext\ntext\ntext" ) ;
 
 if(defined $text && $text ne '')
 	{
+	$self->create_undo_snapshot() ;
+	
 	my ($current_x, $current_y) = ($self->{MOUSE_X}, $self->{MOUSE_Y}) ;
 	my ($separator) = split("\n", $text) ;
 	
 	$text =~ s/$separator\n// ;
 
+	my @new_elements ;
+	
 	for my $element_text (split("$separator\n", $text))
 		{
 		chomp $element_text ;
@@ -373,58 +443,29 @@ if(defined $text && $text ne '')
 							RESIZABLE => 1,
 							}) ;
 							
+		if(! $boxed)
+			{
+			my $box_type = $new_element->get_box_type() ;
+			
+			for  my $box_element (@{$box_type})
+				{
+				$box_element->[0] = 0 ;
+				}
+				
+			$new_element->set_box_type($box_type) ;
+			$new_element->shrink() ;
+			}
+			
 		@$new_element{'X', 'Y'} = ($current_x, $current_y) ;
 		$current_x += $self->{COPY_OFFSET_X} ; 
 		$current_y += $self->{COPY_OFFSET_Y} ;
 		
-		$self->add_elements($new_element) ;
+		push @new_elements , $new_element ;
 		}
-		
-	$self->update_display() ;
-	}
-}
-
-sub insert_multiple_texts_from_text_description
-{
-my ($self) = @_ ;
-
-$self->create_undo_snapshot() ;
-
-my $text = $self->display_edit_dialog('multiple texts from input', "--\ntext\n--\ntext\n--\ntext\n--\ntext" ) ;
-
-if(defined $text && $text ne '')
-	{
-	my ($current_x, $current_y) = ($self->{MOUSE_X}, $self->{MOUSE_Y}) ;
-	my ($separator) = split("\n", $text) ;
 	
-	$text =~ s/$separator\n// ;
-
-	for my $element_text (split("$separator\n", $text))
-		{
-		chomp $element_text ;
-		
-		my $new_element = new App::Asciio::stripes::editable_box2
-							({
-							TITLE => '',
-							TEXT_ONLY => $element_text,
-							BOX_TYPE => 
-								[
-								[0, 'top', '.', '-', '.', 1, ],
-								[0, 'title separator', '.', '-', '.', 1, ],
-								[0, 'body separator', '. ', '|', ' .', 1, ], 
-								[0, 'bottom', '\'', '-', '\'', 1, ],
-								], 
-							EDITABLE => 1,
-							RESIZABLE => 1,
-							}) ;
-							
-		@$new_element{'X', 'Y'} = ($current_x, $current_y) ;
-		$current_x += $self->{COPY_OFFSET_X} ; 
-		$current_y += $self->{COPY_OFFSET_Y} ;
-		
-		$self->add_elements($new_element) ;
-		}
-		
+	$self->deselect_all_elements() ;
+	$self->add_elements(@new_elements) ;
+	$self->select_elements(1, @new_elements) ;
 	$self->update_display() ;
 	}
 }
@@ -435,7 +476,7 @@ sub flip_grid_display
 {
 my ($self) = @_ ;
 $self->{DISPLAY_GRID} ^=1 ;
-$self->update_display();
+$self->update_display() ;
 }
 	
 #----------------------------------------------------------------------------------------------
@@ -444,7 +485,7 @@ sub transparent_elements
 {
 my ($self) = @_ ;
 $self->{OPAQUE_ELEMENTS} ^=1 ;
-$self->update_display();
+$self->update_display() ;
 }
 	
 #----------------------------------------------------------------------------------------------
